@@ -22,7 +22,7 @@ else:
 from datetime import datetime, timedelta, timezone
 
 CONTENT_TYPE="application/arson"
-__version__="0.0.6"
+__version__="0.0.7"
 
 # ARSON tags
 
@@ -46,6 +46,7 @@ allowed_tags_for_list = set("""
         complex string
         i8 i16 i32 i64 i128
         u8 u16 u32 u64 u128
+        f64 
 """.split())
 
 allowed_tags_for_string = set("""
@@ -56,8 +57,6 @@ allowed_tags_for_string = set("""
 
 allowed_tags_for_number = set("""
         object int float duration
-        i8 i16 i32 i64 i128
-        u8 u16 u32 u64 u128
 """.split())
 
 allowed_tags_for_bool = set("""
@@ -343,7 +342,24 @@ class Codec:
                 n_min, n_max = number_widths[name]
                 if not all(isinstance(i, int) and i >= n_min and i <= n_max for i in out):
                     raise ParserErr(buf, pos, "Expecing an array of ints")
-            elif name in ('f8', 'f16', 'f32', 'f64', 'f128',):
+            elif name == 'f64':
+                arr = []
+                for i in out:
+                    if isinstance(i, int):
+                        arr.append(float(i))
+                    elif isinstance(i, float):
+                        arr.append(i)
+                    elif isinstance(i, str):
+                        m = c99_flt.match(out)
+                        if m:
+                            arr.append(float.fromhex(out))
+                        else:
+                            raise ParserErr(
+                                buf, pos, "invalid C99 float literal: {}".format(out))
+                    else:
+                        raise ParserErr(buf, pos, "Expectign an array of floats")
+                out = arr
+            elif name in ('f8', 'f16', 'f32', 'f128'):
                 raise ParserErr(buf, pos, "Unsupported tag {}:".format(repr(name)))
             elif name in reserved_tags:
                 raise ParserErr(
@@ -557,14 +573,6 @@ class Codec:
             elif name == 'float':
                 if not isinstance(out, float):
                     out = float(out)
-            elif name in ('u8', 'u16', 'u32', 'u64', 'u128',):
-                if not isinstance(out, int) or out <= 0:
-                    raise ParserErr(buf, pos, "Expecing a positive int")
-            elif name in ('i8', 'i16', 'i32', 'i64', 'i128',):
-                if not isinstance(out, int):
-                    raise ParserErr(buf, pos, "Expecing an int")
-            elif name in ('f8', 'f16', 'f32', 'f64', 'f128',):
-                raise ParserErr(buf, pos, "Unsupported tag {}:".format(repr(name)))
             elif name in reserved_tags:
                 raise ParserErr(
                     buf, pos, "{} has no meaning for {}".format(repr(name), item))
